@@ -1,6 +1,6 @@
 package DBIx::Class::Migration;
 
-our $VERSION = "0.04_5";
+our $VERSION = "0.04_7";
 $VERSION = eval $VERSION;
 
 use Moose;
@@ -603,7 +603,7 @@ L<DBIx::Class::DeploymentHandler> and L<DBIx::Class::Fixtures>, along with
 a standard tutorial, to give you a simple and straightforward approach to
 solving the problem of how to best create database versions, migrations and
 testing data.  Additionally it builds on tools like L<Test::mysqld> and
-L<Test::postgresql> along with L<DBD::Sqlite> in order to assist you in quickly
+L<Test::PostgreSQL> along with L<DBD::Sqlite> in order to assist you in quickly
 creating a local development database sandbox.  It offers some integration
 points to testing your database, via tools like L<Test::DBIx::Class> in order to
 make testing your database driven logic less painful.  Lastly, we offer some
@@ -660,7 +660,7 @@ an array which can be sent to L<DBIx::Class::Schema/connect>.
 This defaults to L<DBIx::Class::Migration::SqliteSandbox>.  Currently we have
 support for MySQL and Postgresql via L<DBIx::Class::Migration::MySQLSandbox>
 and L<DBIx::Class::Migration::PgSandbox>, but you will need to side install
-L<Test::mysqld> and L<Test::postgresql> (In other words you'd need to add
+L<Test::mysqld> and L<Test::PostgreSQL> (In other words you'd need to add
 these C<Test::*> namespace modules to your C<Makefile.PL> or C<dist.ini>).
 
 =head2 db_sandbox
@@ -1104,7 +1104,7 @@ sets of data.  Lastly, thanks to the L<DBIx::Class> cabal for all the work done
 in making the L<DBIx::Class> ORM so amazingly powerful.
 
 Additionally thanks to the creators / maintainers for L<Test::mysqld> and
-L<Test::postgresql>, which made it easy to create developer level sandboxes for
+L<Test::PostgreSQL>, which made it easy to create developer level sandboxes for
 these popular open source databases.
 
 As usual, thanks to the L<Moose> cabal for making Perl programming fun and
@@ -1137,7 +1137,7 @@ missed you.
 L<DBIx::Class::DeploymentHandler>, L<DBIx::Class::Fixtures>, L<DBIx::Class>,
 L<DBIx::Class::Schema::Loader>, L<Moose>, L<DBIx::Class::Migration::Script>,
 L<DBIx::Class::Migration::Population>, L<dbic-migration>, L<SQL::Translator>,
-L<Test::mysqld>, L<Test::postgresql>.
+L<Test::mysqld>, L<Test::PostgreSQL>.
 
 =head1 COPYRIGHT & LICENSE
 
